@@ -204,7 +204,6 @@ static void update_pixbuf(char *display)
             blue = 0x0;
           }
           /* scale */
-#if 1
           for (l=i*horiz_scale; l<(i*horiz_scale)+horiz_scale; l++) {
             for (m=((j*4)+k)*vertical_scale; m<(((j*4)+k)*vertical_scale)+vertical_scale; m++) {
               p = pixels + m * rowstride + l * n_channels;
@@ -213,12 +212,6 @@ static void update_pixbuf(char *display)
               p[2] = blue;
             }
           }
-#else
-          p = pixels + ((j*4)+k) * rowstride + i * n_channels;
-          p[0] = red;
-          p[1] = green;
-          p[2] = blue;
-#endif
  	} /* for k */
       } /* for j */
     } /* for i */
@@ -768,10 +761,6 @@ connect_to_soundbridge(const gchar *ip_addr)
     if (sockfd == -1) {
       hildon_banner_show_information(GTK_WIDGET(window), NULL,
                              "connect_to_soundbridge: Unable to get socket");
-        if (sockfd != -1) {
-		close(sockfd);
-		sockfd = -1;
-	}
       return FALSE;
     }
     
@@ -1438,7 +1427,7 @@ gint main(gint argc, gchar *argv[])
     
     /* set when running on PC */
 #ifndef ARM /* this doesn't seem to work on the tablet */
-    _iap_connected = TRUE;
+    //_iap_connected = TRUE;
 #endif
 
     osso_iap_cb(iap_callback);
